(function() {var implementors = {};
implementors["alloc"] = [];
implementors["collections"] = [];
implementors["proc_macro"] = [];

            if (window.register_implementors) {
                window.register_implementors(implementors);
            } else {
                window.pending_implementors = implementors;
            }
        
})()
